==> QupZilla-2.2.3.tar.xz: QupZilla-2.2.3/src/plugins/TabManager/translations/pt_PT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_PT" version="2.1">
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Selecione o tipo de visualização:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>Barra lateral</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nota:&lt;/span&gt; Recomendamos o tipo &amp;quot;Janela&amp;quot; se necessitar de gerir muitas janelas ou separadores.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>Utilizar esta extensão como substituta da barra de separadores principal.</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Gestor de separadores</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="106"/>
        <source>Local File System:</source>
        <translation>Sistema de ficheiros local:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="109"/>
        <source>QupZilla:</source>
        <translation>QupZilla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="112"/>
        <source> [FTP]</source>
        <translation> [FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="266"/>
        <source>Group by</source>
        <translation>Agrupar por</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="267"/>
        <source>&amp;Window</source>
        <translation>&amp;Janela</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="272"/>
        <source>&amp;Domain</source>
        <translation>&amp;Domínio</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="277"/>
        <source>&amp;Host</source>
        <translation>Ser&amp;vidor</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="285"/>
        <source>&amp;Show side by side</source>
        <translation>Mo&amp;strar lado a lado</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="291"/>
        <source>&amp;Detach checked tabs</source>
        <translation>S&amp;eparar separadores assinalados</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="292"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>Criar &amp;marcador para os separadores assinalados</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="293"/>
        <source>&amp;Close checked tabs</source>
        <translation>Fe&amp;char os separadores assinalados</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="547"/>
        <source>Choose folder for bookmarks:</source>
        <translation>Escolha a pasta para os marcadores:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="548"/>
        <source>Bookmark Selected Tabs</source>
        <translation>Criar marcador para os separadores selecionados</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="665"/>
        <source>Window %1</source>
        <translation>Janela %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="666"/>
        <source>Double click to switch</source>
        <translation>Duplo clique para trocar</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="46"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="51"/>
        <source>Tab Manager</source>
        <translation>Gestor de separadores</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="79"/>
        <source>Show Tab Manager</source>
        <translation>Mostrar gestor de separadores</translation>
    </message>
</context>
</TS>

==> QupZilla-2.2.5.tar.xz: QupZilla-2.2.5/src/plugins/TabManager/translations/pt_PT.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pt_PT" version="2.1">
<context>
    <name>TabManagerButton</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="50"/>
        <source>Tab Manager button</source>
        <translation>Botão Gestor de separadores</translation>
    </message>
</context>
<context>
    <name>TabManagerSettings</name>
    <message>
        <location filename="../tabmanagersettings.ui" line="14"/>
        <source>Tab Manager Settings</source>
        <translation>Definições</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="20"/>
        <source>View</source>
        <translation>Ver</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="26"/>
        <source>Please select view type:</source>
        <translation>Selecione o tipo de visualização:</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="33"/>
        <source>SideBar</source>
        <translation>Barra lateral</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="40"/>
        <source>Window</source>
        <translation>Janela</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="47"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Note:&lt;/span&gt; The &amp;quot;Window&amp;quot; type is recommended for managing lots of windows/tabs.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Nota:&lt;/span&gt; Recomendamos o tipo &amp;quot;Janela&amp;quot; se necessitar de gerir muitas janelas ou separadores.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../tabmanagersettings.ui" line="60"/>
        <source>Use TabManager plugin as replacement for main TabBar.</source>
        <translation>Utilizar esta extensão como substituta da barra de separadores principal.</translation>
    </message>
</context>
<context>
    <name>TabManagerWidget</name>
    <message>
        <location filename="../tabmanagerwidget.ui" line="14"/>
        <source>Tab Manager</source>
        <translation>Gestor de separadores</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="110"/>
        <source>Local File System:</source>
        <translation>Sistema de ficheiros local:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="113"/>
        <source>QupZilla:</source>
        <translation>QupZilla:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="116"/>
        <source> [FTP]</source>
        <translation> [FTP]</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="301"/>
        <source>Group by</source>
        <translation>Agrupar por</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="302"/>
        <source>&amp;Window</source>
        <translation>&amp;Janela</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="307"/>
        <source>&amp;Domain</source>
        <translation>&amp;Domínio</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="312"/>
        <source>&amp;Host</source>
        <translation>Ser&amp;vidor</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="320"/>
        <source>&amp;Show side by side</source>
        <translation>Mo&amp;strar lado a lado</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="326"/>
        <source>&amp;Detach checked tabs</source>
        <translation>S&amp;eparar separadores assinalados</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="327"/>
        <source>Book&amp;mark checked tabs</source>
        <translation>Criar &amp;marcador para os separadores assinalados</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="328"/>
        <source>&amp;Close checked tabs</source>
        <translation>Fe&amp;char os separadores assinalados</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="329"/>
        <source>&amp;Unload checked tabs</source>
        <translation>Descarregar separadores &amp;marcados</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="581"/>
        <source>Choose folder for bookmarks:</source>
        <translation>Escolha a pasta para os marcadores:</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="582"/>
        <source>Bookmark Selected Tabs</source>
        <translation>Criar marcador para os separadores selecionados</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="700"/>
        <source>Window %1</source>
        <translation>Janela %1</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidget.cpp" line="701"/>
        <source>Double click to switch</source>
        <translation>Duplo clique para trocar</translation>
    </message>
</context>
<context>
    <name>TabManagerWidgetController</name>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="68"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="73"/>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="99"/>
        <source>Tab Manager</source>
        <translation>Gestor de separadores</translation>
    </message>
    <message>
        <location filename="../tabmanagerwidgetcontroller.cpp" line="100"/>
        <source>Show Tab Manager</source>
        <translation>Mostrar gestor de separadores</translation>
    </message>
</context>
</TS>
